#
# spec file for package hypre
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor openmpi5%{?nil}
%define somver %{_ver}
%define sover %{ver}

# Base package name
%define pname hypre
%define PNAME %(echo %{pname} | tr [a-z] [A-Z])

%if 0%{?sle_version} >= 150200
%define DisOMPI1 ExclusiveArch:  do_not_build
%endif
%if !0%{?is_opensuse} && 0%{?sle_version:1} && 0%{?sle_version} < 150200
%define DisOMPI3 ExclusiveArch:  do_not_build
%endif
%if 0%{?sle_version:1} && 0%{?sle_version} < 150300
%define DisOMPI4 ExclusiveArch:  do_not_build
%endif

%if "%flavor" == ""
%define package_name %{pname}
ExclusiveArch:  do_not_build
%endif

%if "%{flavor}" == "serial"
%undefine mpi_family
%endif

%if "%{flavor}" == "openmpi4"
%global mpi_family  openmpi
%define mpi_vers 4
%{?DisOMPI4}
%endif

%if "%{flavor}" == "openmpi5"
%global mpi_family  openmpi
%define mpi_vers 5
%{?DisOMPI5}
%endif

%if "%{flavor}" == "mvapich2"
%global mpi_family  mvapich2
%endif

%if "%{flavor}" == "mpich"
%global mpi_family  mpich
%endif

%{?mpi_family:%{bcond_without mpi}}%{!?mpi_family:%{bcond_with mpi}}

# For compatibility package names
%if "%{mpi_family}" != "openmpi" || "%{mpi_vers}" != "1" || 0%{?suse_version} > 1500
%define mpi_ext %{?mpi_vers}
%endif

%if %{without mpi}
 %global my_bindir %_bindir
 %global _incdir %{_prefix}/include/
%else
 %global _bindir %_bindir
 %global _defaultlicensedir %_defaultlicensedir
 %global _prefix %{_libdir}/mpi/gcc/%{mpi_family}%{?mpi_ext}
 %global _suffix -%{?mpi_family}%{?mpi_ext}
 %global my_bindir %{_prefix}/bin
 %global _libdir %{_prefix}/%{_lib}/
 %global _incdir %{_prefix}/include/
%endif
%if 0%{!?package_name:1}
  %define package_name   %pname%{?_suffix}
%endif
%define libname  lib%{PNAME}%{somver}%{?_suffix}

Name:           %package_name
Version:        2.20.0
%define somver 2_20_0
Release:        4.1
Summary:        Scalable algorithms for solving linear systems of equations
License:        Apache-2.0 OR MIT
Group:          Productivity/Scientific/Math
URL:            https://www.llnl.gov/casc/hypre/
Source:         https://github.com/hypre-space/hypre/archive/v%{version}.tar.gz#/hypre-%{version}.tar.gz
Patch0:         hypre_Makefile_examples.patch
Patch1:         Add-library-version.patch

# TODO : add babel
#BuildRequires:  babel-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  lapack-devel
BuildRequires:  superlu-devel
%if 0%{?with mpi}
BuildRequires:  %{mpi_family}%{?mpi_ext}-devel
%endif
BuildRequires:  cmake
BuildRequires:  fdupes
# Default library install path

%description
Hypre is a library of preconditioners that feature parallel multigrid
methods for both structured and unstructured grid problems arising in
the simulation codes being developed at LLNL to study physical
phenomena in the defense, environmental, energy, and biological
sciences.

%package     -n %{libname}
Summary:        Scalable algorithms for solving linear systems of equations
Group:          System/Libraries

%description -n %{libname}
Hypre is a library of preconditioners that feature parallel multigrid
methods for both structured and unstructured grid problems arising in
the simulation codes being developed at LLNL to study physical
phenomena in the defense, environmental, energy, and biological
sciences.

This package contains %{?mpi_family}%{?mpi_vers}%{!?mpi_family:serial} shared libraries of Hypre.

%package devel
Summary:        Headers and library links for %{libname}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %version
Requires:       lapack-devel
Requires:       superlu-devel

%description devel
%{PNAME} headers and libraries files needed for development
This package contains development files of the %{?mpi_family}%{?mpi_vers}%{!?mpi_family:serial} version of Hypre.

%package        examples
Summary:        Examples for Hypre
Group:          Documentation/Other
BuildArch:      noarch

%description    examples
This package contains examples for Hypre.

%package        doc
Summary:        Development documentation for Hypre
Group:          Documentation/Other
BuildArch:      noarch
BuildRequires:  texlive-bibtex
BuildRequires:  texlive-latex-bin-bin
BuildRequires:  texlive-xypic

%description    doc
This package contains development documentation for Hypre.

%prep
%autosetup -p0 -n %{pname}-%{version}

cat > %{_sourcedir}/baselibs.conf  <<EOF
%{libname}
%{libname}-devel
  requires %{?_suffix}-<targettype>
  requires "%{libname}-<targettype> = <version>"
EOF

%build
%{?with_mpi: . %{my_bindir}/mpivars.sh}

export LDFLAGS="-lm"

cd src/
%cmake \
       -DHYPRE_SHARED=ON \
       %if %{without mpi}
       -DHYPRE_WITH_MPI=OFF \
       %else
       -DHYPRE_WITH_MPI=ON \
       %endif
       -DHYPRE_USING_HYPRE_BLAS=OFF \
       -DHYPRE_USING_HYPRE_LAPACK=OFF \
       -DCMAKE_SHARED_LINKER_FLAGS="-lm"

%make_jobs

%install
cd src/
install -m 644 -D docs/usr-manual/*pdf -t %{buildroot}%{_docdir}/%{package_name}/
%fdupes -s examples

%cmake_install

%fdupes -s %{buildroot}%{_prefix}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/*.so.*

%files devel
%{_libdir}/cmake
%license COPYRIGHT LICENSE-APACHE LICENSE-MIT NOTICE
%doc CHANGELOG README.md INSTALL.md
%{_incdir}/%{pname}
%{_libdir}/*.so

%files doc
%{_docdir}/%{package_name}

%files examples
%doc src/examples

%changelog
* Mon Mar 31 2025 Egbert Eich <eich@suse.com>
- Remove support for gnu-hpc build flavors (bsc#1239982).
* Mon Mar 24 2025 Nicolas Morey <nicolas.morey@suse.com>
- Disable gnu-hpc build flavours (bsc#1239982)
- Add openmpi5 build flavour
- openmpi5 is not available on 32b systems
* Tue Dec  3 2024 Egbert Eich <eich@suse.com>
- Use the newly introduced %%hpc_requires_eq macro to get the correct
  library dependencies (boo#1234007).
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Oct 23 2023 Egbert Eich <eich@suse.com>
- Disable HPC flavors on i586
* Mon Oct 23 2023 Nicolas Morey <nicolas.morey@suse.com>
- Drop support for obsolete openmpi[123]
- Prepare support for openmpi5
* Fri Jan 29 2021 Egbert Eich <eich@suse.com>
- Make cmake files installation non-conflicting.
* Fri Jan 29 2021 Egbert Eich <eich@suse.com>
- Fix hypre package conflicts for non HPC packages.
* Thu Jan 28 2021 Egbert Eich <eich@suse.com>
- Change 'Requires:' to other HPC packages to %%requires_eq to depend
  on the exact version. This should take care of HPC packages ignoring
  proper ABI versioning.
* Mon Jan 25 2021 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to 2.20.0
  * New matrix-based interpolation routines for AMG (CPU and GPU)
  * Added GPU support for aggressive coarsening in AMG
  * New AMG-DD solver
  * Improved distributed sparse matrix-matrix and triple-matrix product
    performance on GPUs
  * IJMatrix/Vector assembly on GPUs (with pointers to GPU memory)
  * Updated caliper usage
  * Separated C and C++ headers
  * Updated to support superlu-dist version to 6.3.1
  * Moved reference manual API to online documentation
  * New AMG features to keep specified F-points and/or C-points.
  * Added GPU support for AMG setup and several interpolation approaches.
  * New parallel ILU solvers and smoothers.
  * New MGR features.
  * Added several interpolation routines based on matrix-matrix interpolations.
  * Various bug fixes.
- Remove patch merged by upstream
  * Fix-empty-elseif-in-CMakeLists.txt.patch
- Rework patch following upstream changes
  * Fix-library-version-numbering.patch Patch removed
  * Add-library-version.patch Patch added
* Wed Oct  7 2020 Egbert Eich <eich@suse.com>
- Don't include superlu-devel and lapack-devel into HPC devel
  package.
* Fri Sep 11 2020 Egbert Eich <eich@suse.com>
- Add build support for gcc10 to HPC build (bsc#1174439).
- Add openmpi4 flavors.
* Tue May  5 2020 Egbert Eich <eich@suse.com>
- Add non-HPC openmpi3 flavor.
* Fri Apr 17 2020 Egbert Eich <eich@suse.com>
- Enable non-HPC openmpi3 build (boo#1169792).
- Remove bogus %%undefine suffix - suffix is a RPM builtin, and
  trying to undefine it is an error since RPM 4.15.
* Fri Nov 29 2019 Egbert Eich <eich@suse.com>
- Add support for gcc7.
- Add support for gcc8 and gcc9 (jsc#SLE-7766 & jsc#SLE-8604).
* Thu Nov 28 2019 Egbert Eich <eich@suse.com>
- Update to 2.18.2:
  * Fixed mixedint bugs.
  * Ported BoomerAMG setup to run on GPUs.  Only a subset of setup phase
    features are currently available.
  * Updated CMake to support more of the features available in configure/make.
  * Added RecomputeResidual options to several hybrid solvers.
  * Various bug fixes.
- Disable openmpi1 builds for SLE/Leap > 15.1.
- Adapt build for openmpi1 to reflect naming change on Factory.
- Enable openmpi3 builds for Leap and SLE > 15.1 (jsc#SLE-7773).
- hypre_CMakeLists.patch refreshed and replaced by:
  Fix-library-version-numbering.patch
- Fix-empty-elseif-in-CMakeLists.txt.patch:
  Fix empty elseif() in CMake file.
- Use full package version to identify .so version:
  INSTALL.md states that "The hypre team currently does nothing to ensure
  application binary interface (ABI) compatibility. As a result, all release
  (major, minor, or patch) should be treated as incompatible."
- Replaced -DHYPRE_SEQUENTIAL by -DHYPRE_WITH_MPI
* Mon Sep  2 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Documentation is only available online now. Remove the -doc package.
* Thu Aug 29 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- New version 2.17.0 (jsc#SLE-8498)
  * Changed open source license to dual MIT/Apache-2.0
  * Removed FEI_mv/ml subdirectory and several FEI header files
  * Various bug fixes.
  * Added new '--enable-mixedint' configure option.
  * Various GPU optimizations
  * Changed documentation to use Sphinx and Doxygen.
- Update License field to reflect the new dual licensing.
- Update source, there is a new GitHub group for hypre.
- Refresh patches:
  * hypre_Makefile_examples.patch
  * hypre_CMakeLists.patch
* Wed Feb 27 2019 Egbert Eich <eich@suse.com>
- Build the examples and docs as a separate HPC package.
- Made example and doc packages 'noarch'.
- Remove duplicates from examples.
- Fix rpmlint warnings about macros in comments.
- Fix library path to work both on 32 and 64 bit.
* Tue Feb 26 2019 cgoll@suse.com
- Switched to cmake build system to fix boo#1126367
  * added hypre_CMakeLists.patch for proper version numbering
  * added dependency for lapack and superlu devel for non hpc builds
- Due to boo#1127070 does not compile for mvapich2/mpich
* Wed Feb 13 2019 Antoine Ginies <aginies@suse.com>
- Add a sub examples package to test in prod env
  Add: hypre_Makefile_examples.patch
* Sun Feb 10 2019 Egbert Eich <eich@suse.com>
- Properly create and tear down default version links when the
  HPC master packages are installed/uninstalled.
- Fix dependencies for HPC.
- Add dependency to HPC modulefile.
- Fix package groups.
- Add pkgconfig file.
- Consolidate use of openmpi1, openmpi2, openmpi3 for non-HPC builds.
* Fri Jan 25 2019 eich@suse.com
- Disable openmpi1 builds on SLE.
* Mon Jan 14 2019 eich@suse.com
- Fix yet another library dependency.
* Mon Jan 14 2019 eich@suse.com
- Fix HPC libname for master package.
* Sun Jan 13 2019 eich@suse.com
- Disable openmpi3 builds on SLE.
* Sat Jan 12 2019 Jan Engelhardt <jengelh@inai.de>
- Trim future goals, trim filler wording.
* Mon Jan  7 2019 eich@suse.com
- Add more MPI flavors.
- Create baselib.conf on the fly.
- Do not build non-HPC on SLE to save build cycles.
- Remove babel_files: not used anywhere.
- Remove unneeded BuildRequires:.
* Mon Jan  7 2019 cgoll@suse.com
- Added HPC support.
* Sun Jan  6 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2.15.1
- Drop hypre-2.8.0b-no-date-and-time-fix.patch
- Convert to multibuild for openmpi/openmpi2
* Thu Aug  2 2012 scorot@free.fr
- add baselibs.conf
- build serial version
- fix shared libs package name
* Thu Aug  2 2012 scorot@free.fr
- patch0
- move %%%%doc files to devel package
* Mon Jul 30 2012 scorot@free.fr
- add mvapich2 build for SLE 11
* Sun Jul 29 2012 scorot@free.fr
- fist package based on alt linux spec file
